==> discover-5.26.5-1.src.tar.gz: discover-5.26.5/discover/org.kde.discover.desktop.cmake <==
[Desktop Entry]
Name=Discover
Name[ar]=المستكشف
Name[ast]=Discover
Name[az]=Discover
Name[bg]=Discover
Name[ca]=Discover
Name[ca@valencia]=Discover
Name[cs]=Discover
Name[da]=Discover
Name[de]=Discover
Name[el]=Discover
Name[en_GB]=Discover
Name[es]=Discover
Name[et]=Discover
Name[eu]=Discover
Name[fi]=Discover
Name[fr]=Discover
Name[gl]=Descubrir
Name[he]=Discover
Name[hi]=डिस्कवर
Name[hu]=Discover
Name[ia]=Discover (Discoperi)
Name[id]=Discover
Name[it]=Discover
Name[ja]=Discover
Name[ka]=Discover
Name[ko]=Discover
Name[lt]=Discover
Name[ml]=കണ്ടെത്തുക
Name[my]=ဒစ်(စ)ကာဗာ
Name[nl]=Ontdekken
Name[nn]=Discover
Name[pa]=ਡਿਸਕਵਰ
Name[pl]=Odkrywca
Name[pt]=Discover
Name[pt_BR]=Discover
Name[ro]=Discover
Name[ru]=Discover
Name[sk]=Discover
Name[sl]=Discover
Name[sr]=Oткривач
Name[sr@ijekavian]=Oткривач
Name[sr@ijekavianlatin]=Otkrivač
Name[sr@latin]=Otkrivač
Name[sv]=Upptäck
Name[tg]=Кашфиёт
Name[tr]=Keşfet
Name[uk]=Discover
Name[x-test]=xxDiscoverxx
Name[zh_CN]=Discover 软件管理中心
Name[zh_TW]=Discover
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=plasmadiscover
Type=Application
X-DocPath=plasma-discover/index.html
InitialPreference=5
NoDisplay=@DesktopNoDisplay@
Actions=Updates;
SingleMainWindow=true
GenericName=Software Center
GenericName[ar]=مركز البرمجيّات
GenericName[ast]=Centru de software
GenericName[az]=Proqram Təminatı Mərkəzi
GenericName[bg]=Софтуерен център
GenericName[ca]=Centre de programari
GenericName[ca@valencia]=Centre de programari
GenericName[cs]=Centrum softwaru
GenericName[da]=Softwarecenter
GenericName[de]=Programmverwaltung
GenericName[el]=Κέντρο λογισμικού
GenericName[en_GB]=Software Centre
GenericName[es]=Centro de software
GenericName[et]=Tarkvarakeskus
GenericName[eu]=Software gunea
GenericName[fi]=Sovellusvalikoima
GenericName[fr]=Logithèque
GenericName[gl]=Centro de Software
GenericName[he]=מרכז התכנה
GenericName[hi]=सॉफ्टवेयर केन्द्र
GenericName[hsb]=Srjedźišćo za software
GenericName[hu]=Szoftverközpont
GenericName[ia]=Centro de Software
GenericName[id]=Pusat Perangkat Lunak
GenericName[it]=Software Center
GenericName[ja]=ソフトウェアセンター
GenericName[ka]=პროგრამების ცენტრი
GenericName[ko]=소프트웨어 센터
GenericName[lt]=Programinės įrangos centras
GenericName[ml]=സോഫ്റ്റ്വെയർ സെന്റർ
GenericName[my]=ဆော့ဖ်ဝဲလ်စင်တာ
GenericName[nb]=Programvaresenter
GenericName[nl]=Softwarecentrum
GenericName[nn]=Programvaresenter
GenericName[pa]=ਸਾਫਟਵੇਅਰ ਸੈਂਟਰ
GenericName[pl]=Ośrodek programów
GenericName[pt]=Centro de Aplicações
GenericName[pt_BR]=Central de aplicativos
GenericName[ro]=Centru de aplicații
GenericName[ru]=Центр программ
GenericName[sk]=Centrum softvéru
GenericName[sl]=Programsko središče
GenericName[sr]=Софтверски центар
GenericName[sr@ijekavian]=Софтверски центар
GenericName[sr@ijekavianlatin]=Softverski centar
GenericName[sr@latin]=Softverski centar
GenericName[sv]=Programvarucentral
GenericName[tg]=Маркази нармафзор
GenericName[tr]=Yazılım Merkezi
GenericName[uk]=Центр програм
GenericName[x-test]=xxSoftware Centerxx
GenericName[zh_CN]=软件管理中心程序
GenericName[zh_TW]=軟體中心
Categories=Qt;KDE;System;
Keywords=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[ar]=برنامج;برمجيّة;برمجية;مستودع;حزمة;تثبيت;إزالة;أرشيف;تحديث;تطبيقات;تطبيق;
Keywords[az]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;proqram;proqram təminatı;anbar;paket;əlavə edin;quraşdırın;silin;ləğv edin;yeniləyin;tətbiqlər; tətbiqetmələr;oyunlar;əlavələr
Keywords[bg]=програма;софтуер;хранилище;пакет;инсталиране;премахване;актуализация;програми;приложения;
Keywords[ca]=programa;programari;repositori;paquet;afegeix;instal·la;desinstal·la;elimina;actualitza;apps;aplicacions;jocs;flatpak;snap;complements;microprogramari;firmware;
Keywords[ca@valencia]=programa;programari;repositori;paquet;afig;instal·la;desinstal·la;elimina;actualitza;apps;aplicacions;jocs;flatpak;snap;complements;microprogramari;firmware;
Keywords[de]=Programm;Software;Archiv;Paket;Installieren;Deinstallieren;Entfernen;Aktualisieren;Programme;Anwendungen;Spiele;
Keywords[en_GB]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[es]=programa;software;repositorio;paquete;añadir;agregar;instalar;desinstalar;eliminar;borrar;actualizar;apps;aplicaciones;juegos;flatpak;snap;complementos;añadidos;firmware;
Keywords[eu]=programa;softwarea;gordetegia;paketea;gehitu;instalatu;desinstalatu;kendu;eguneratu;appak;aplikazioak;jokoak;flatpak;snap;gehigarriak;firmwarea;
Keywords[fi]=ohjelma;ohjelmisto;asennuslähde;repositorio;paketti;lisää;asenna;asennus;poista asennus;poista;päivitä;päivitys;sovellus;sovellukset;peli;pelit;flatpak;snap;lisäosa;lisäosat;laiteohjelma;varusohjelma
Keywords[fr]=programme ; logiciel ; dépôt ; paquet ; ajout ; installation ; désinstallation ; suppression ; mise à jour ; apps ; applications ; jeux ; flatpak ; snap ; modules externes ; micrologiciel ;
Keywords[hu]=program;szoftver;tároló;csomag;hozzáadás;telepítés;eltávolítás;törlés;frissítés;alkalmazások;alkalmazások;játékok;flatpak;snap;bővítmények;kiterjesztések;firmware;
Keywords[ia]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[id]=program;perangkat lunak;repositori;paket;tambah;instal;uninstal;hapus;hilangkan;app;aplikasi;game;permainan;snap;addon;pernik;pernak-pernik;firmware;
Keywords[it]=programma;software;deposito;pacchetto;installa;disinstalla;rimuovi;aggiorna;app;applicazioni;giochi;flatpak;snap;componenti aggiuntivi;firmware;
Keywords[ka]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[ko]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;프로그램;소프트웨어;저장소;리포지토리;패키지;꾸러미;추가;설치;삭제;업데이트;앱;게임;추가 기능;부가 기능;펌웨어;
Keywords[nl]=programma;software;opslagruimte;pakket;toevoegen;installeren;installatie ongedaan maken;verwijderen;bijwerken;apps;toepassingen;applicaties;spellen;flatpak;snap;add-ons;firmware;
Keywords[nn]=program;programvare;pakkebrønn;pakke;pakkar;legg til;leggja til;installera;installering;avinstallera;avinstallering;fjerna;fjerning;oppdatera;oppdatering;app;appar;applikasjonar;spel;dataspel;flatpak;snap;tillegg;programtillegg;fastvare;
Keywords[pa]=ਪਰੋਗਰਾਮ;ਸਾਫਟਵੇਅਰ;ਰਿਪੋਜ਼ਟਰੀ;ਪੈਕੇਜ;ਇੰਸਟਾਲ;ਪ੍ਰੋਗਰਾਮ;ਇੰਸਟਾਲ;ਹਟਾਓ;ਮਿਟਾਓ;ਅੱਪਡੇਟ;ਐਪ;ਐਪਲੀਕੇਸ਼ਨਾਂ;ਅਣ-ਇੰਸਟਾਲ;ਖੇਡਾਂ;ਗੇਮਾਂ;ਫਲੈਟਪੈਕ;ਸਨੈਪ;ਐਡ-ਆਨ;ਐਡਆਨ;ਫਿਰਮਵੇਅਰ;ਫਰਮਵੇਅਰ;ਜੋੜੋ;
Keywords[pl]=program;oprogramowanie;repozytorium;archiwum;pakiet;paczka;dodaj;instaluj;zainstaluj;usuń;odinstaluj;uaktualnij;aktualizuj;programy;aplikacje;deb;gry;flatpak;snap;dodatki;oprogramowanie układowe;
Keywords[pt]=programa;software;repositório;pacote;instalar;remover;actualizar;aplicações;jogos;flatpak;snap;extensões;firmware;
Keywords[pt_BR]=programa;software;repositório;pacote;adicionar;instalar;desinstalar;remover;atualizar;aplicativos;apps;aplicações;jogos;flatpak;snap;complemento;extensão;firmware;
Keywords[ro]=program;software;depozit;pachet;instalare;eliminare;actualizare;aplicații;instalează;elimină;actualizează;jocuri;flatpak;snap;suplimente;firmware;microcod;
Keywords[ru]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;программа;приложение;репозиторий;пакет;добавить;установка;удаление;deb;игры;расширения;прошивка
Keywords[sk]=program;softvér;repozitár;balík;inštalácia;inľtalovať;odstránenie;odstrániť;aktualizovať;aktualizácia;appky;aplikácie;
Keywords[sl]=program;programska oprema;skladišče;paket;dodaj;namesti;odstrani;posodobi;programi;aplikacije;igre;flatpak;posnetek;dodatki;vgrajeno programje;
Keywords[sv]=program;programvara;arkiv;paket;lägg till;installera;avinstallera;ta bort;uppdatera;appar;program;spel;flatpak;snap;tillägg;fast programvara
Keywords[tr]=program;yazılım;depo;paket;ekle;kur;kaldır;güncelle;uygulama;uygulamalar;oyunlar;flatpak;snap;eklentiler;gömülü yazılım
Keywords[uk]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;програма;програмне забезпечення;сховище;архів;пакунок;додати;встановити;встановлення;вилучити;вилучення;оновлення;оновити;ігри;флетпак;снеп;снап;додатки;мікропрограма;
Keywords[x-test]=xxprogramxx;xxsoftwarexx;xxrepositoryxx;xxpackagexx;xxaddxx;xxinstallxx;xxuninstallxx;xxremovexx;xxupdatexx;xxappsxx;xxapplicationsxx;xxgamesxx;xxflatpakxx;xxsnapxx;xxaddonsxx;xxadd-onsxx;xxfirmwarexx;
Keywords[zh_CN]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;程序;软件;仓库;软件包;添加;安装;卸载;移除;升级;应用;应用程序;游戏;扩展程序;附加程序;固件;
Keywords[zh_TW]=program;software;repository;package;install;remove;update;apps;applications;軟體;程式;軟體包;軟體庫;安裝;移除;更新;

[Desktop Action Updates]
Name=See Available Updates
Name[ar]=اعرض التحديثات المتوفرة
Name[az]=Əlçatan yenilənmələrə baxın
Name[bg]=Преглед на наличие актуализации
Name[ca]=Mostra les actualitzacions disponibles
Name[ca@valencia]=Mostra les actualitzacions disponibles
Name[cs]=Zobrazit dostupné aktualizace
Name[de]=Zeigt verfügbare Aktualisierungen
Name[en_GB]=See Available Updates
Name[es]=Ver las actualizaciones disponibles
Name[eu]=Ikusi eguneratze erabilgarriak
Name[fi]=Näytä saatavilla olevat päivitykset
Name[fr]=Consulter les mises à jour disponibles
Name[hi]=उपलब्ध अद्यतन देखें
Name[hsb]=Pokaž móžne aktualizowanja
Name[hu]=Elérhető frissítések megtekintése
Name[ia]=Vide actualisationes dispoibile
Name[id]=Lihat Pembaruan Tersedia
Name[it]=Vedi gli aggiornamenti disponibili
Name[ka]=ხელმისაწვდომი განახლებების ნახვა
Name[ko]=사용 가능한 업데이트 보기
Name[lt]=Rodyti prieinamus atnaujinimus
Name[ml]=ലഭ്യമായ അപ്ഡേറ്റുകൾ കാണുക
Name[my]=ရရှိနိုင်သော အပ်ဒိတ်များ ကြည့်မည်
Name[nl]=Zie beschikbare elementen voor bijwerken
Name[nn]=Sjå tilgjengelege oppdateringar
Name[pa]=ਮੌਜੂਦ ਅੱਪਡੇਟ ਵੇਖੋ
Name[pl]=Obejrzyj dostępne uaktualnienia
Name[pt]=Ver as Actualizações Disponíveis
Name[pt_BR]=Ver as atualizações disponíveis
Name[ro]=Vezi actualizările disponibile
Name[ru]=Просмотреть доступные обновления
Name[sk]=Zobraziť dostupné aktualizácie
Name[sl]=Poglej razpoložljive posodobitve
Name[sv]=Se Tillgängliga uppdateringar
Name[tr]=Kullanılabilir Güncellemeleri Gör
Name[uk]=Перегляд доступних оновлень
Name[x-test]=xxSee Available Updatesxx
Name[zh_CN]=查看可用更新
Name[zh_TW]=檢視可用的更新
Icon=update-low
Exec=plasma-discover --mode update

==> discover-5.27.5-1.1.src.tar.gz: discover-5.27.5/discover/org.kde.discover.desktop.cmake <==
[Desktop Entry]
Name=Discover
Name[ar]=المستكشف
Name[az]=Discover
Name[bg]=Discover
Name[ca]=Discover
Name[ca@valencia]=Discover
Name[cs]=Discover
Name[da]=Discover
Name[de]=Discover
Name[el]=Discover
Name[en_GB]=Discover
Name[es]=Discover
Name[et]=Discover
Name[eu]=Discover
Name[fi]=Discover
Name[fr]=Discover
Name[gl]=Descubrir
Name[he]=Discover
Name[hi]=डिस्कवर
Name[hu]=Discover
Name[ia]=Discover (Discoperi)
Name[id]=Discover
Name[ie]=Discover
Name[it]=Discover
Name[ja]=Discover
Name[ka]=Discover
Name[ko]=Discover
Name[lt]=Discover
Name[ml]=കണ്ടെത്തുക
Name[my]=ဒစ်(စ)ကာဗာ
Name[nb]=Discover
Name[nl]=Ontdekken
Name[nn]=Discover
Name[pa]=ਡਿਸਕਵਰ
Name[pl]=Odkrywca
Name[pt]=Discover
Name[pt_BR]=Discover
Name[ro]=Discover
Name[ru]=Discover
Name[sk]=Discover
Name[sl]=Discover
Name[sr]=Oткривач
Name[sr@ijekavian]=Oткривач
Name[sr@ijekavianlatin]=Otkrivač
Name[sr@latin]=Otkrivač
Name[sv]=Upptäck
Name[ta]=டிஸ்கவர்
Name[tg]=Кашфиёт
Name[tr]=Keşfet
Name[uk]=Discover
Name[x-test]=xxDiscoverxx
Name[zh_CN]=Discover 软件管理中心
Name[zh_TW]=Discover
MimeType=@DesktopMimeType@
Exec=@DesktopExec@
Icon=plasmadiscover
Type=Application
X-DocPath=plasma-discover/index.html
InitialPreference=5
NoDisplay=@DesktopNoDisplay@
Actions=Updates;
SingleMainWindow=true
GenericName=Software Center
GenericName[ar]=مركز البرمجيّات
GenericName[az]=Proqram Təminatı Mərkəzi
GenericName[bg]=Софтуерен център
GenericName[ca]=Centre de programari
GenericName[ca@valencia]=Centre de programari
GenericName[cs]=Centrum softwaru
GenericName[da]=Softwarecenter
GenericName[de]=Programmverwaltung
GenericName[el]=Κέντρο λογισμικού
GenericName[en_GB]=Software Centre
GenericName[es]=Centro de software
GenericName[et]=Tarkvarakeskus
GenericName[eu]=Software gunea
GenericName[fi]=Sovellusvalikoima
GenericName[fr]=Logithèque
GenericName[gl]=Centro de Software
GenericName[he]=מרכז התכנה
GenericName[hi]=सॉफ्टवेयर केन्द्र
GenericName[hsb]=Srjedźišćo za software
GenericName[hu]=Szoftverközpont
GenericName[ia]=Centro de Software
GenericName[id]=Pusat Perangkat Lunak
GenericName[ie]=Programmarium
GenericName[it]=Software Center
GenericName[ja]=ソフトウェアセンター
GenericName[ka]=პროგრამების ცენტრი
GenericName[ko]=소프트웨어 센터
GenericName[lt]=Programinės įrangos centras
GenericName[ml]=സോഫ്റ്റ്വെയർ സെന്റർ
GenericName[my]=ဆော့ဖ်ဝဲလ်စင်တာ
GenericName[nb]=Programvaresenter
GenericName[nl]=Softwarecentrum
GenericName[nn]=Programvaresenter
GenericName[pa]=ਸਾਫਟਵੇਅਰ ਸੈਂਟਰ
GenericName[pl]=Ośrodek programów
GenericName[pt]=Centro de Aplicações
GenericName[pt_BR]=Central de aplicativos
GenericName[ro]=Centru de aplicații
GenericName[ru]=Центр программ
GenericName[sk]=Centrum softvéru
GenericName[sl]=Programsko središče
GenericName[sr]=Софтверски центар
GenericName[sr@ijekavian]=Софтверски центар
GenericName[sr@ijekavianlatin]=Softverski centar
GenericName[sr@latin]=Softverski centar
GenericName[sv]=Programvarucentral
GenericName[ta]=மென்பொருள் மையம்
GenericName[tg]=Маркази нармафзор
GenericName[tr]=Yazılım Merkezi
GenericName[uk]=Центр програм
GenericName[x-test]=xxSoftware Centerxx
GenericName[zh_CN]=软件管理中心程序
GenericName[zh_TW]=軟體中心
Categories=Qt;KDE;System;
Keywords=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[ar]=برنامج;برمجيّة;برمجية;مستودع;حزمة;تثبيت;إزالة;أرشيف;تحديث;تطبيقات;تطبيق;
Keywords[az]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;proqram;proqram təminatı;anbar;paket;əlavə edin;quraşdırın;silin;ləğv edin;yeniləyin;tətbiqlər; tətbiqetmələr;oyunlar;əlavələr
Keywords[bg]=програма;софтуер;хранилище;пакет;инсталиране;премахване;актуализация;програми;приложения;
Keywords[ca]=programa;programari;repositori;paquet;afegeix;instal·la;desinstal·la;elimina;actualitza;apps;aplicacions;jocs;flatpak;snap;complements;microprogramari;firmware;
Keywords[ca@valencia]=programa;programari;repositori;paquet;afig;instal·la;desinstal·la;elimina;actualitza;apps;aplicacions;jocs;flatpak;snap;complements;microprogramari;firmware;
Keywords[cs]=program;software;repozitář;balíček;přidat;instalovat;odinstalovat;odstranit;aktualizovat;programy;aplikace;hry;flatpak;snap;doplňky;addony;firmware;
Keywords[de]=Programm;Software;Archiv;Paket;Installieren;Deinstallieren;Entfernen;Aktualisieren;Programme;Anwendungen;Spiele;
Keywords[en_GB]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[es]=programa;software;repositorio;paquete;añadir;agregar;instalar;desinstalar;eliminar;borrar;actualizar;apps;aplicaciones;juegos;flatpak;snap;complementos;añadidos;firmware;
Keywords[eu]=programa;softwarea;gordetegia;paketea;gehitu;instalatu;desinstalatu;kendu;eguneratu;appak;aplikazioak;jokoak;flatpak;snap;gehigarriak;firmwarea;
Keywords[fi]=ohjelma;ohjelmisto;asennuslähde;repositorio;paketti;lisää;asenna;asennus;poista asennus;poista;päivitä;päivitys;sovellus;sovellukset;peli;pelit;flatpak;snap;lisäosa;lisäosat;laiteohjelma;varusohjelma;
Keywords[fr]=programme ; logiciel ; dépôt ; paquet ; ajout ; installation ; désinstallation ; suppression ; mise à jour ; applications ; applications ; jeux ; flatpak ; snap ; modules externes ; micrologiciel ;
Keywords[hu]=program;szoftver;tároló;csomag;hozzáadás;telepítés;eltávolítás;törlés;frissítés;alkalmazások;alkalmazások;játékok;flatpak;snap;bővítmények;kiterjesztések;firmware;
Keywords[ia]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[id]=program;perangkat lunak;repositori;paket;tambah;instal;uninstal;hapus;hilangkan;app;aplikasi;game;permainan;snap;addon;pernik;pernak-pernik;firmware;
Keywords[ie]=programma;repositoria;paccage;adjunter;installar;deinstallar;actualisar;app;applicationes;ludes;flatpak;snap;addons;add-ons;firmware;
Keywords[it]=programma;software;deposito;pacchetto;installa;disinstalla;rimuovi;aggiorna;app;applicazioni;giochi;flatpak;snap;componenti aggiuntivi;firmware;
Keywords[ja]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;インストール;アンインストール;アプリケーション;ソフトウェア;更新;削除;リポジトリ;アドオン;ゲーム;パッケージ;ファームウェア;
Keywords[ka]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;
Keywords[ko]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;프로그램;소프트웨어;저장소;리포지토리;패키지;꾸러미;추가;설치;삭제;업데이트;앱;게임;추가 기능;부가 기능;펌웨어;
Keywords[nb]=program;programvare;pakkebrønn;pakke;legg til;installer;avinstaller;fjern;oppdater;apper;applikasjoner;spill;flatpak;snap;tillegg;programtillegg;fastvare;
Keywords[nl]=programma;software;opslagruimte;pakket;toevoegen;installeren;installatie ongedaan maken;verwijderen;bijwerken;apps;toepassingen;applicaties;spellen;flatpak;snap;add-ons;firmware;
Keywords[nn]=program;programvare;pakkebrønn;pakke;pakkar;legg til;leggja til;installera;installering;avinstallera;avinstallering;fjerna;fjerning;oppdatera;oppdatering;app;appar;applikasjonar;spel;dataspel;flatpak;snap;tillegg;programtillegg;fastvare;
Keywords[pa]=ਪਰੋਗਰਾਮ;ਸਾਫਟਵੇਅਰ;ਰਿਪੋਜ਼ਟਰੀ;ਪੈਕੇਜ;ਇੰਸਟਾਲ;ਪ੍ਰੋਗਰਾਮ;ਇੰਸਟਾਲ;ਹਟਾਓ;ਮਿਟਾਓ;ਅੱਪਡੇਟ;ਐਪ;ਐਪਲੀਕੇਸ਼ਨਾਂ;ਅਣ-ਇੰਸਟਾਲ;ਖੇਡਾਂ;ਗੇਮਾਂ;ਫਲੈਟਪੈਕ;ਸਨੈਪ;ਐਡ-ਆਨ;ਐਡਆਨ;ਫਿਰਮਵੇਅਰ;ਫਰਮਵੇਅਰ;ਜੋੜੋ;
Keywords[pl]=program;oprogramowanie;repozytorium;archiwum;pakiet;paczka;dodaj;instaluj;zainstaluj;usuń;odinstaluj;uaktualnij;aktualizuj;programy;aplikacje;deb;gry;flatpak;snap;dodatki;oprogramowanie układowe;
Keywords[pt]=programa;software;repositório;pacote;instalar;remover;actualizar;aplicações;jogos;flatpak;snap;extensões;firmware;
Keywords[pt_BR]=programa;software;repositório;pacote;adicionar;instalar;desinstalar;remover;atualizar;aplicativos;apps;aplicações;jogos;flatpak;snap;complemento;extensão;firmware;
Keywords[ro]=program;software;depozit;pachet;instalare;eliminare;actualizare;aplicații;instalează;elimină;actualizează;jocuri;flatpak;snap;suplimente;firmware;microcod;
Keywords[ru]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;программа;приложение;репозиторий;пакет;добавить;установка;удаление;deb;игры;расширения;прошивка
Keywords[sk]=program;softvér;repozitár;balík;inštalácia;inľtalovať;odstránenie;odstrániť;aktualizovať;aktualizácia;appky;aplikácie;
Keywords[sl]=program;programska oprema;skladišče;paket;dodaj;namesti;odstrani;posodobi;programi;aplikacije;igre;flatpak;posnetek;dodatki;vgrajeno programje;
Keywords[sv]=program;programvara;arkiv;paket;lägg till;installera;avinstallera;ta bort;uppdatera;appar;program;spel;flatpak;snap;tillägg;fast programvara
Keywords[ta]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;மென்பொருள்;பயன்பாடு;செயலி;ஆப்ஸ்;ஆப்சு;நிரல்;கிடங்கு;களஞ்சியம்;தொகுப்பு;சேர்;நிறுவு;நிறுவல்;நீக்கு;புதுப்பி;புதுப்பித்தல்;ஃபலாட்பாக்;ஸ்னாப்;சுனாப்;செருகுநிரல்;துணை நிரல்கள்;துணைநிரல்;சாதனநிரல்;
Keywords[tr]=program;yazılım;depo;paket;ekle;kur;kaldır;güncelle;uygulama;uygulamalar;oyunlar;flatpak;snap;eklentiler;gömülü yazılım
Keywords[uk]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;програма;програмне забезпечення;сховище;архів;пакунок;додати;встановити;встановлення;вилучити;вилучення;оновлення;оновити;ігри;флетпак;снеп;снап;додатки;мікропрограма;
Keywords[x-test]=xxprogramxx;xxsoftwarexx;xxrepositoryxx;xxpackagexx;xxaddxx;xxinstallxx;xxuninstallxx;xxremovexx;xxupdatexx;xxappsxx;xxapplicationsxx;xxgamesxx;xxflatpakxx;xxsnapxx;xxaddonsxx;xxadd-onsxx;xxfirmwarexx;
Keywords[zh_CN]=program;software;repository;package;add;install;uninstall;remove;update;apps;applications;games;flatpak;snap;addons;add-ons;firmware;程序;软件;仓库;软件包;添加;安装;卸载;移除;升级;应用;应用程序;游戏;扩展程序;附加程序;固件;
Keywords[zh_TW]=program;software;repository;package;install;remove;update;apps;applications;軟體;程式;軟體包;軟體庫;安裝;移除;更新;

[Desktop Action Updates]
Name=See Available Updates
Name[ar]=اعرض التحديثات المتوفرة
Name[az]=Əlçatan yenilənmələrə baxın
Name[bg]=Преглед на наличие актуализации
Name[ca]=Mostra les actualitzacions disponibles
Name[ca@valencia]=Mostra les actualitzacions disponibles
Name[cs]=Zobrazit dostupné aktualizace
Name[de]=Zeigt verfügbare Aktualisierungen
Name[en_GB]=See Available Updates
Name[es]=Ver las actualizaciones disponibles
Name[eu]=Ikusi eguneratze erabilgarriak
Name[fi]=Näytä saatavilla olevat päivitykset
Name[fr]=Consulter les mises à jour disponibles
Name[hi]=उपलब्ध अद्यतन देखें
Name[hsb]=Pokaž móžne aktualizowanja
Name[hu]=Elérhető frissítések megtekintése
Name[ia]=Vide actualisationes dispoibile
Name[id]=Lihat Pembaruan Tersedia
Name[ie]=Vider li disponibil actualisamentes
Name[it]=Vedi gli aggiornamenti disponibili
Name[ja]=利用可能な更新を見る
Name[ka]=ხელმისაწვდომი განახლებების ნახვა
Name[ko]=사용 가능한 업데이트 보기
Name[lt]=Rodyti prieinamus atnaujinimus
Name[ml]=ലഭ്യമായ അപ്ഡേറ്റുകൾ കാണുക
Name[my]=ရရှိနိုင်သော အပ်ဒိတ်များ ကြည့်မည်
Name[nb]=Se tilgjengelige oppdateringer
Name[nl]=Zie beschikbare elementen voor bijwerken
Name[nn]=Sjå tilgjengelege oppdateringar
Name[pa]=ਮੌਜੂਦ ਅੱਪਡੇਟ ਵੇਖੋ
Name[pl]=Obejrzyj dostępne uaktualnienia
Name[pt]=Ver as Actualizações Disponíveis
Name[pt_BR]=Ver as atualizações disponíveis
Name[ro]=Vezi actualizările disponibile
Name[ru]=Просмотреть доступные обновления
Name[sk]=Zobraziť dostupné aktualizácie
Name[sl]=Poglej razpoložljive posodobitve
Name[sv]=Se Tillgängliga uppdateringar
Name[ta]=கிடைக்கும் புதுப்பிப்புகளை காட்டும்
Name[tr]=Kullanılabilir Güncellemeleri Gör
Name[uk]=Перегляд доступних оновлень
Name[x-test]=xxSee Available Updatesxx
Name[zh_CN]=查看可用更新
Name[zh_TW]=檢視可用的更新
Icon=update-low
Exec=plasma-discover --mode update
